@@ -2,7 +2,8 @@ import argparse
 import os
 import pmjsonparser.parser
 
-if __name__ == "__main__":
+
+def main():
   parser = argparse.ArgumentParser(description='Process JSON to generate postgres snippets')
   parser.add_argument('json_source', type=str, help='path of the json file to be parsed')
   parser.add_argument('json_target', type=str, help='target path resulting postman file')
@@ -19,3 +20,7 @@ if __name__ == "__main__":
     print('could not find json path at' + json_source_path)
     exit(1)
   pmjsonparser.parser.run(json_source_path, json_target_path, js_target_path, prefix)
+
+
+if __name__ == "__main__":
+  main()
\ No newline at end of file
